Learn R Programming

SuperLearner (version 2.0-9)

SuperLearnerNews: Show the NEWS file for the SuperLearner package

Description

Show the NEWS file of the SuperLearner package. The function is simply a wrapper for the RShowDoc function

Usage

SuperLearnerNews(...)
SuperLearnerDocs(what = 'SuperLearnerR.pdf', ...)

Arguments

...
additional arguments passed to RShowDoc
what
specify what document to open. Currently supports the NEWS file and the PDF files 'SuperLearner.pdf' and 'SuperLearnerR.pdf'.

Value

  • A invisible character string given the path to the SuperLearner NEWS file